==> geeklog-1.5.0-jp-0.5.tar.gz: geeklog-1.5.0-jp-0.5/plugins/polls/language/estonian.php <==
<?php

###############################################################################
# estonian.php
# This is the estonian language page for the Geeklog Polls Plug-in
#
# Copyright (C) 2001 Tony Bibbs
# tony@tonybibbs.com
# Copyright (C) 2005 Trinity Bays
# trinity93@gmail.com
#
# Estonian translation by Artur Rpp <rtr AT planet DOT ee>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
###############################################################################

global $LANG32;

###############################################################################
# Array Format:
# $LANGXX[YY]:  $LANG - variable name
#               XX    - file id number
#               YY    - phrase id number
###############################################################################

$LANG_POLLS = array(
    'polls' => 'Ksitlused',
    'results' => 'Tulemused',
    'pollresults' => 'Hletuste tulemused',
    'votes' => 'Hletust',
    'vote' => 'Hleta',
    'pastpolls' => 'Viimased ksitlused',
    'savedvotetitle' => 'Hl salvestatud',
    'savedvotemsg' => 'Sinu hl on salvestatud. Hletasid ksitluses:',
    'pollstitle' => 'Olemas olevad ksitlused',
    'polltopics' => 'Other polls',
    'stats_top10' => 'Top 10 ksitlust',
    'stats_topics' => 'Poll Topic',
    'stats_votes' => 'hli',
    'stats_none' => 'Nib et sellel lehel pole htegi ksitlust vi mitte keegi ei ole veel hletanud.',
    'stats_summary' => 'Ksitlusi (vastuseid)',
    'open_poll' => 'Avatud hletamiseks',
    'answer_all' => 'Palun vasta kigile lejnud ksimustele',
    'not_saved' => 'Tulemus pole salvestatud',
    'upgrade1' => 'Installeerisid ksitluste plugina uue versiooni. Palun ',
    'upgrade2' => 'uuenda',
    'editinstructions' => 'Palun sisesta ksitluse ID, vhemalt ks ksitluse ksimus ning sellele ksimusele vhemalt kaks vastusevarianti'  
    );

###############################################################################
# admin/plugins/polls/index.php

$LANG25 = array(
    1 => 'Reiim',
    2 => 'Palun sisesta rubriik, vhemalt ks ksimus ja sellele ksimusele vhemalt ks vastusevariant', 
    3 => 'Ksitlus on loodud',
    4 => 'Ksitlus %s salvestatud',
    5 => 'Toimeta ksitlust',
    6 => 'Ksitluse ID',
    7 => '(ra kasuta thikuid)',
    8 => 'Nhtav ksitluseblokis',
    9 => 'Rubriik',
    10 => 'Vastused / hletused / mrkus',
    11 => 'Ksitluse  %s vastusteinfo laadimisel tekkis viga ',
    12 => 'Ksitluse  %s ksimusteinfo laadimisel tekkis viga',
    13 => 'Loo ksitlus',
    14 => 'Salvesta',
    15 => 'Thista',
    16 => 'Kustuta',
    17 => 'Palun sisesta ksitluse ID',
    18 => 'Ksitluste loetelu',
    19 => 'Ksitluse toimetamiseks vi kustutamiseks klpsa ksitluse toimetamisikooni. Uue ksitluse loomiseks klpsa "Uus ksitlus" lal.',  
    20 => 'Hletajad',
    21 => 'Ligips tkestatud',
    22 => "Sa ritasid ligi pseda ksitlusele, milleks pole sul igust. See katse on logitud. Palun <a href=\"{$_CONF['site_admin_url']}/poll.php\">mine tagasi ksitluste haldamislehele</a>.",
    23 => 'Uus ksitlus',
    24 => 'Admin avaleht',
    25 => 'Jah',
    26 => 'Ei',
    27 => 'Toimeta',
    28 => 'Sisesta',
    29 => 'Otsi',
    30 => 'Piira tulemusi',
    31 => 'Ksimus',
    32 => 'Selle ksimuse ksitlusest eemaldamiseks, kustuta ksimuse tekst',
    33 => 'Avatud hletamiseks',
    34 => 'Ksitluse rubriik:',
    35 => 'Selles ksitluses on veel',
    36 => 'ksimust',
    37 => 'Peida tulemused kuni ksitlus on avatud',
    38 => 'Kuni ksitlus on avatud, nevad  &tulemusi ainult omanik amp; root ',
    39 => 'Rubriiki nidatakse vaid siis, kui selles on le he ksimuse.',
    40 => 'Vaata kiki sellele ksitlusele antud vastuseid'
);

$PLG_polls_MESSAGE19 = 'Sinu ksitlus on edukalt salvestatud.';
$PLG_polls_MESSAGE20 = 'Sinu ksitlus on edukalt kustutatud.';

// Messages for the plugin upgrade
$PLG_polls_MESSAGE3001 = 'Plugina uuendamine pole toetatud.';
$PLG_polls_MESSAGE3002 = $LANG32[9];

// Localization of the Admin Configuration UI
$LANG_configsections['polls'] = array(
    'label' => 'Ksitlused',
    'title' => 'Ksitluste haldur'
);

$LANG_confignames['polls'] = array(
    'pollsloginrequired' => 'Ksitlused vajavad sisselogimist?',
    'hidepollsmenu' => 'Peida ksitluste menpunkt?',
    'maxquestions' => 'Maks. ksimusi ksitluses',
    'maxanswers' => 'Maks. vastusevariante',
    'answerorder' => 'Sorteeri tulemusi ...',
    'pollcookietime' => 'Hletuskpsise kehtivusaeg',
    'polladdresstime' => 'Hletaja IP Aadress kehtib kuni',
    'delete_polls' => 'Kustuta ksitlused, omanikuks?',
    'aftersave' => 'Prast ksitluse salvestamist',
    'default_permissions' => 'Ksitluse vaikimisi igused'
);

$LANG_configsubgroups['polls'] = array(
    'sg_main' => 'Peahlestused'
);

$LANG_fs['polls'] = array(
    'fs_main' => 'Ksitluste ldised hlestused',
    'fs_permissions' => 'Vaikimisi igused'
);

// Note: entries 0, 1, and 12 are the same as in $LANG_configselects['Core']
$LANG_configselects['polls'] = array(
    0 => array('True' => 1, 'False' => 0),
    1 => array('True' => true, 'False' => false),
    2 => array('As Submitted' => 'submitorder', 'By Votes' => 'voteorder'),
    9 => array('Forward to Poll' => 'item', 'Display Admin List' => 'list', 'Display Public List' => 'plugin', 'Display Home' => 'home', 'Display Admin' => 'admin'),
    12 => array('No access' => 0, 'Read-Only' => 2, 'Read-Write' => 3)
);

?>

==> geeklog-1.8.2-jp-1.0.tar.gz: geeklog-1.8.2-jp-1.0/plugins/polls/language/estonian.php <==
<?php

###############################################################################
# estonian.php
# This is the Estonian language file for the Geeklog Polls plugin
#
# Copyright (C) 2001 Tony Bibbs
# tony@tonybibbs.com
# Copyright (C) 2005 Trinity Bays
# trinity93@gmail.com
#
# Estonian translation by Artur Rpp <rtr AT planet DOT ee>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
###############################################################################

global $LANG32;

###############################################################################
# Array Format:
# $LANGXX[YY]:  $LANG - variable name
#               XX    - file id number
#               YY    - phrase id number
###############################################################################

$LANG_POLLS = array(
    'polls' => 'Ksitlused',
    'results' => 'Tulemused',
    'pollresults' => 'Hletuste tulemused',
    'votes' => 'Hletust',
    'voters' => 'voters',
    'vote' => 'Hleta',
    'pastpolls' => 'Viimased ksitlused',
    'savedvotetitle' => 'Hl salvestatud',
    'savedvotemsg' => 'Sinu hl on salvestatud. Hletasid ksitluses:',
    'pollstitle' => 'Olemas olevad ksitlused',
    'polltopics' => 'Other polls',
    'stats_top10' => 'Top 10 ksitlust',
    'stats_topics' => 'Poll Topic',
    'stats_votes' => 'hli',
    'stats_none' => 'Nib et sellel lehel pole htegi ksitlust vi mitte keegi ei ole veel hletanud.',
    'stats_summary' => 'Ksitlusi (vastuseid)',
    'open_poll' => 'Avatud hletamiseks',
    'answer_all' => 'Palun vasta kigile lejnud ksimustele',
    'not_saved' => 'Tulemus pole salvestatud',
    'upgrade1' => 'Installeerisid ksitluste plugina uue versiooni. Palun ',
    'upgrade2' => 'uuenda',
    'editinstructions' => 'Palun sisesta ksitluse ID, vhemalt ks ksitluse ksimus ning sellele ksimusele vhemalt kaks vastusevarianti',
    'pollclosed' => 'This poll is closed for voting.',
    'pollhidden' => 'You have already voted. This poll results will only be shown when voting is closed.',
    'start_poll' => 'Kivita ksitlus',
    'no_new_polls' => 'No new polls',
    'autotag_desc_poll' => '[poll: id alternate title] - Displays a link to a poll using the Poll Topic as the title. An alternate title may be specified but is not required.',
    'autotag_desc_poll_vote' => '[poll_vote: id class:poll-autotag showall:1] - Displays a poll for voting. Class and showall not required. Class specifies the css class and Showall if set to 1, shows all questions',
    'autotag_desc_poll_result' => '[poll_result: id class:poll-autotag] - Displays the poll results. Class not required. Class specifies the css class.',
    'deny_msg' => 'Access to this poll is denied.  Either the poll has been moved/removed or you do not have sufficient permissions.'
);

###############################################################################
# admin/plugins/polls/index.php

$LANG25 = array(
    1 => 'Reiim',
    2 => 'Palun sisesta rubriik, vhemalt ks ksimus ja sellele ksimusele vhemalt ks vastusevariant',
    3 => 'Ksitlus on loodud',
    4 => 'Ksitlus %s salvestatud',
    5 => 'Toimeta ksitlust',
    6 => 'Ksitluse ID',
    7 => '(ra kasuta thikuid)',
    8 => 'Nhtav ksitluseblokis',
    9 => 'Rubriik',
    10 => 'Vastused / hletused / mrkus',
    11 => 'Ksitluse  %s vastusteinfo laadimisel tekkis viga ',
    12 => 'Ksitluse  %s ksimusteinfo laadimisel tekkis viga',
    13 => 'Loo ksitlus',
    14 => 'Salvesta',
    15 => 'Thista',
    16 => 'Kustuta',
    17 => 'Palun sisesta ksitluse ID',
    18 => 'Ksitluste loetelu',
    19 => 'Ksitluse toimetamiseks vi kustutamiseks klpsa ksitluse toimetamisikooni. Uue ksitluse loomiseks klpsa "Uus ksitlus" lal.',
    20 => 'Hletajad',
    21 => 'Ligips tkestatud',
    22 => "Sa ritasid ligi pseda ksitlusele, milleks pole sul igust. See katse on logitud. Palun <a href=\"{$_CONF['site_admin_url']}/poll.php\">mine tagasi ksitluste haldamislehele</a>.",
    23 => 'Uus ksitlus',
    24 => 'Admin avaleht',
    25 => 'Jah',
    26 => 'Ei',
    27 => 'Toimeta',
    28 => 'Sisesta',
    29 => 'Otsi',
    30 => 'Piira tulemusi',
    31 => 'Ksimus',
    32 => 'Selle ksimuse ksitlusest eemaldamiseks, kustuta ksimuse tekst',
    33 => 'Avatud hletamiseks',
    34 => 'Ksitluse rubriik:',
    35 => 'Selles ksitluses on veel',
    36 => 'ksimust',
    37 => 'Peida tulemused kuni ksitlus on avatud',
    38 => 'Kuni ksitlus on avatud, nevad  &tulemusi ainult omanik amp; root ',
    39 => 'Rubriiki nidatakse vaid siis, kui selles on le he ksimuse.',
    40 => 'Vaata kiki sellele ksitlusele antud vastuseid'
);

$PLG_polls_MESSAGE15 = 'Sinu kommentaar on suunatud lbivaatamiseks. See ilmub lehele prast moderaatorite poolset kinnitamist.';
$PLG_polls_MESSAGE19 = 'Sinu ksitlus on edukalt salvestatud.';
$PLG_polls_MESSAGE20 = 'Sinu ksitlus on edukalt kustutatud.';

// Messages for the plugin upgrade
$PLG_polls_MESSAGE3001 = 'Plugina uuendamine pole toetatud.';
$PLG_polls_MESSAGE3002 = $LANG32[9];

// Localization of the Admin Configuration UI
$LANG_configsections['polls'] = array(
    'label' => 'Ksitlused',
    'title' => 'Ksitluste haldur'
);

$LANG_confignames['polls'] = array(
    'pollsloginrequired' => 'Ksitlused vajavad sisselogimist?',
    'hidepollsmenu' => 'Peida ksitluste menpunkt?',
    'maxquestions' => 'Maks. ksimusi ksitluses',
    'maxanswers' => 'Maks. vastusevariante',
    'answerorder' => 'Sorteeri tulemusi ...',
    'pollcookietime' => 'Hletuskpsise kehtivusaeg',
    'polladdresstime' => 'Hletaja IP Aadress kehtib kuni',
    'delete_polls' => 'Kustuta ksitlused, omanikuks?',
    'aftersave' => 'Prast ksitluse salvestamist',
    'default_permissions' => 'Ksitluse vaikimisi igused',
    'autotag_permissions_poll' => '[poll: ] Permissions',
    'autotag_permissions_poll_vote' => '[poll_vote: ] Permissions',
    'autotag_permissions_poll_result' => '[poll_result: ] Permissions',
    'newpollsinterval' => 'New Polls Interval',
    'hidenewpolls' => 'New Polls',
    'title_trim_length' => 'Title Trim Length',
    'meta_tags' => 'Luba Meta sildid'
);

$LANG_configsubgroups['polls'] = array(
    'sg_main' => 'Peahlestused'
);

$LANG_tab['polls'] = array(
    'tab_main' => 'General Polls Settings',
    'tab_whatsnew' => 'What\'s New Block',
    'tab_permissions' => 'Default Permissions',
    'tab_autotag_permissions' => 'Autotag Usage Permissions'
);

$LANG_fs['polls'] = array(
    'fs_main' => 'Ksitluste ldised hlestused',
    'fs_whatsnew' => 'What\'s New Block',
    'fs_permissions' => 'Vaikimisi igused',
    'fs_autotag_permissions' => 'Autotag Usage Permissions'
);

// Note: entries 0, 1, and 12 are the same as in $LANG_configselects['Core']
$LANG_configselects['polls'] = array(
    0 => array('Jah' => 1, 'Ei' => 0),
    1 => array('Jah' => true, 'Ei' => false),
    2 => array('Nagu sisestatud' => 'submitorder', 'Hlte jrgi' => 'voteorder'),
    5 => array('Hide' => 'hide', 'Show - Use Modified Date' => 'modified', 'Show - Use Created Date' => 'created'),
    9 => array('Suuna ksitluste juurde' => 'item', 'Nita administreerimisloetelu' => 'list', 'Nita avalikku loetelu' => 'plugin', 'Nita avalehte' => 'home', 'Nita administreerimislehte' => 'admin'),
    12 => array('Pole ligipsu' => 0, 'Ainult loetav' => 2, 'Loetav ja muudetav' => 3),
    13 => array('No access' => 0, 'Use' => 2)
);

?>
